@@ -1,3 +1,4 @@
 max.freqtab <- function(x, ..., na.rm = FALSE) {
-  max(x[as.logical(x[, ncol(x)]), 1])
+
+	return(max(x[as.logical(x[, ncol(x)]), 1]))
 }
