@@ -1,3 +1,4 @@
 min.freqtab <- function(x, ..., na.rm = FALSE) {
-  min(x[as.logical(x[, ncol(x)]), 1])
+
+	return(min(x[as.logical(x[, ncol(x)]), 1]))
 }
